;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "aio" "20251117.644"
  "Async/await for Emacs Lisp."
  '((emacs "26.1"))
  :url "https://github.com/skeeto/emacs-aio"
  :commit "58157e51e7eb7a4b954894ee4182564c507a2f01"
  :revdesc "58157e51e7eb"
  :authors '(("Christopher Wellons" . "wellons@nullprogram.com"))
  :maintainers '(("Christopher Wellons" . "wellons@nullprogram.com")))
